@@ -7,12 +7,14 @@ from meilisearch.errors import (
     MeiliSearchCommunicationError,
     MeiliSearchTimeoutError,
 )
+from meilisearch.version import qualified_version
 
 class HttpRequests:
     def __init__(self, config: Config) -> None:
         self.config = config
         self.headers = {
-            'X-Meili-Api-Key': self.config.api_key,
+            'Authorization': f'Bearer {self.config.api_key}',
+            'User-Agent': qualified_version(),
         }
 
     def send_request(
@@ -60,6 +62,14 @@ class HttpRequests:
     ) -> Any:
         return self.send_request(requests.post, path, body, content_type)
 
+    def patch(
+        self,
+        path: str,
+        body: Optional[Union[Dict[str, Any], List[Dict[str, Any]], List[str], str]] = None,
+        content_type: Optional[str] = 'application/json',
+    ) -> Any:
+        return self.send_request(requests.patch, path, body, content_type)
+
     def put(
         self,
         path: str,
