@@ -27,6 +27,8 @@ class Config:
         sortable_attributes = 'sortable-attributes'
         typo_tolerance = 'typo-tolerance'
         dumps = 'dumps'
+        pagination = 'pagination'
+        faceting = 'faceting'
 
     def __init__(
         self,
