@@ -71,7 +71,7 @@ class Index():
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
         payload = {'primaryKey': primary_key}
-        return self.http.put(f'{self.config.paths.index}/{self.uid}', payload)
+        return self.http.patch(f'{self.config.paths.index}/{self.uid}', payload)
 
     def fetch_info(self) -> 'Index':
         """Fetch the info of the index.
@@ -124,20 +124,30 @@ class Index():
         payload = {**options, 'uid': uid}
         return HttpRequests(config).post(config.paths.index, payload)
 
-    def get_tasks(self) -> Dict[str, List[Dict[str, Any]]]:
+    def get_tasks(self, parameters: Optional[Dict[str, Any]] = None) -> Dict[str, List[Dict[str, Any]]]:
         """Get all tasks of a specific index from the last one.
 
+        Parameters
+        ----------
+        parameters (optional):
+            parameters accepted by the get tasks route: https://docs.meilisearch.com/reference/api/tasks.html#get-all-tasks.
+            `indexUid` should be set as a List.
+
         Returns
         -------
         task:
-            Dictionary containing a list of all enqueued, processing, succeeded or failed tasks of the index.
+            Dictionary with limit, from, next and results containing a list of all enqueued, processing, succeeded or failed tasks of the index.
 
         Raises
         ------
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return get_tasks(self.config, self.uid)
+        if parameters is not None:
+            parameters.setdefault('indexUid', []).append(self.uid)
+        else:
+            parameters = {'indexUid': [self.uid]}
+        return get_tasks(self.config, parameters=parameters)
 
     def get_task(self, uid: int) -> Dict[str, Any]:
         """Get one task through the route of a specific index.
@@ -157,7 +167,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return get_task(self.config, uid, self.uid)
+        return get_task(self.config, uid)
 
     def wait_for_task(
         self, uid: int,
@@ -239,13 +249,15 @@ class Index():
             body=body
         )
 
-    def get_document(self, document_id: str) -> Dict[str, Any]:
+    def get_document(self, document_id: str, parameters: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
         """Get one document with given document identifier.
 
         Parameters
         ----------
         document_id:
             Unique identifier of the document.
+        parameters (optional):
+            parameters accepted by the get document route: https://docs.meilisearch.com/reference/api/documents.html#get-one-document
 
         Returns
         -------
@@ -257,22 +269,26 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
+        if parameters is None:
+            parameters = {}
+        elif 'fields' in parameters and isinstance(parameters['fields'], list):
+            parameters['fields'] = ",".join(parameters['fields'])
         return self.http.get(
-            f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}/{document_id}'
+            f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}/{document_id}?{parse.urlencode(parameters)}'
         )
 
-    def get_documents(self, parameters: Optional[Dict[str, Any]] = None) -> List[Dict[str, Any]]:
+    def get_documents(self, parameters: Optional[Dict[str, Any]] = None) -> Dict[str, Any]:
         """Get a set of documents from the index.
 
         Parameters
         ----------
         parameters (optional):
-            parameters accepted by the get documents route: https://docs.meilisearch.com/reference/api/documents.html#get-all-documents
+            parameters accepted by the get documents route: https://docs.meilisearch.com/reference/api/documents.html#get-documents
 
         Returns
         -------
         document:
-            List of dictionaries containing the documents information.
+            Dictionary with limit, offset, total and results a list of dictionaries containing the documents information.
 
         Raises
         ------
@@ -281,6 +297,8 @@ class Index():
         """
         if parameters is None:
             parameters = {}
+        elif 'fields' in parameters and isinstance(parameters['fields'], list):
+            parameters['fields'] = ",".join(parameters['fields'])
         return self.http.get(
             f'{self.config.paths.index}/{self.uid}/{self.config.paths.document}?{parse.urlencode(parameters)}'
         )
@@ -638,7 +656,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.patch(
             f'{self.config.paths.index}/{self.uid}/{self.config.paths.setting}',
             body
         )
@@ -701,7 +719,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.ranking_rules),
             body
         )
@@ -762,7 +780,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.distinct_attribute),
             body
         )
@@ -823,7 +841,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.searchable_attributes),
             body
         )
@@ -884,7 +902,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.displayed_attributes),
             body
         )
@@ -945,7 +963,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.stop_words),
             body
         )
@@ -1006,7 +1024,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.synonyms),
             body
         )
@@ -1067,7 +1085,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.filterable_attributes),
             body
         )
@@ -1129,7 +1147,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.put(
             self.__settings_url_for(self.config.paths.sortable_attributes),
             body
         )
@@ -1190,7 +1208,7 @@ class Index():
         MeiliSearchApiError
             An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
         """
-        return self.http.post(
+        return self.http.patch(
             self.__settings_url_for(self.config.paths.typo_tolerance),
             body
         )
@@ -1213,6 +1231,122 @@ class Index():
             self.__settings_url_for(self.config.paths.typo_tolerance),
         )
 
+    def get_pagination_settings(self) -> Dict[str, Any]:
+        """Get pagination settngs of the index.
+
+        Returns
+        -------
+        settings: dict
+            Dictionary containing the pagination settings of the index.
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.get(self.__settings_url_for(self.config.paths.pagination))
+
+    def update_pagination_settings(self, body: Dict[str, Any]) -> Dict[str, Any]:
+        """Update the pagination settings of the index.
+
+        Parameters
+        ----------
+        body: dict
+            Dictionary containing the pagination settings.
+            https://docs.meilisearch.com/reference/api/pagination.html#update-pagination-settings
+
+        Returns
+        -------
+        task:
+            Dictionary containing a task to track the informations about the progress of an asynchronous process.
+            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.patch(
+            path=self.__settings_url_for(self.config.paths.pagination),
+            body=body
+        )
+
+
+    def reset_pagination_settings(self) -> Dict[str, Any]:
+        """Reset pagination settings of the index to default values.
+
+        Returns
+        -------
+        task:
+            Dictionary containing a task to track the informations about the progress of an asynchronous process.
+            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.delete(self.__settings_url_for(self.config.paths.pagination))
+
+    def get_faceting_settings(self) -> Dict[str, Any]:
+        """Get the faceting settings of an index.
+
+        Returns
+        -------
+        settings: dict
+            Dictionary containing the faceting settings of the index.
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+
+        return self.http.get(self.__settings_url_for(self.config.paths.faceting))
+
+    def update_faceting_settings(self, body: Dict[str, Any]) -> Dict[str, Any]:
+        """Update the faceting settings of the index.
+
+        Parameters
+        ----------
+        body: dict
+            Dictionary containing the faceting settings.
+            https://docs.meilisearch.com/reference/api/faceting.html#update-faceting-settings
+
+        Returns
+        -------
+        task:
+            Dictionary containing a task to track the informations about the progress of an asynchronous process.
+            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.patch(
+            path=self.__settings_url_for(self.config.paths.faceting),
+            body=body
+        )
+
+
+    def reset_faceting_settings(self) -> Dict[str, Any]:
+        """Reset faceting settings of the index to default values.
+
+        Returns
+        -------
+        task:
+            Dictionary containing a task to track the informations about the progress of an asynchronous process.
+            https://docs.meilisearch.com/reference/api/tasks.html#get-one-task
+
+        Raises
+        ------
+        MeiliSearchApiError
+            An error containing details about why Meilisearch can't process your request. Meilisearch error codes are described here: https://docs.meilisearch.com/errors/#meilisearch-errors
+        """
+        return self.http.delete(self.__settings_url_for(self.config.paths.faceting))
+
+
     @staticmethod
     def _batch(
         documents: List[Dict[str, Any]], batch_size: int
